@@ -9,13 +9,13 @@
 #' need to explicit mention grouping variables (or use  `by_group = TRUE`)
 #' in order to group by them, and functions of variables are evaluated
 #' once per data frame, not once per group.
-#' 
+#'
 #' @importFrom dplyr arrange
-#' 
+#'
 #' @details
 #' ## Locales
 #' The sort order for character vectors will depend on the collating sequence
-#' of the locale in use: see [locales()].
+#' of the locale in use: see locales().
 #'
 #' ## Missing values
 #' Unlike base sorting with `sort()`, `NA` are:
@@ -29,24 +29,18 @@
 #' * Columns are not modified.
 #' * Groups are not modified.
 #' * Data frame attributes are preserved.
-#' @section Methods:
-#' This function is a **generic**, which means that packages can provide
-#' implementations (methods) for other classes. See the documentation of
-#' individual methods for extra arguments and differences in behaviour.
 #'
-#' The following methods are currently available in loaded packages:
-#' 
 #' @rdname dplyr-methods
 #' @name arrange
-#' 
+#'
 #' @export
 #' @param .data A data frame, data frame extension (e.g. a tibble), or a
 #'   lazy data frame (e.g. from dbplyr or dtplyr). See *Methods*, below, for
 #'   more details.
 #' @param ... <[`tidy-eval`][dplyr_eval]> Variables, or functions or
-#'   variables. Use [desc()] to sort a variable in descending order.
+#'   variables. Use desc() to sort a variable in descending order.
 #' @param .by_group If TRUE, will sort first by grouping variable. Applies to grouped data frames only.
-#' 
+#'
 #' @family single table verbs
 #' @examples
 #' `%>%` = magrittr::`%>%`
@@ -54,23 +48,23 @@
 NULL
 
 #' @importFrom tibble as_tibble
-#' 
+#'
 #' @export
 #' @inheritParams arrange
 arrange.Seurat <- function(.data, ..., .by_group = FALSE) {
-  
 
-  .data@meta.data = 
-    .data %>% 
+
+  .data@meta.data =
+    .data %>%
     as_tibble() %>%
     dplyr::arrange(  ..., .by_group = .by_group  ) %>%
-    as_meta_data(.data) 
-  
+    as_meta_data(.data)
+
   .data
-  
+
 }
 
- 
+
 
 #' Efficiently bind multiple data frames by row and column
 #'
@@ -91,7 +85,7 @@ arrange.Seurat <- function(.data, ..., .by_group = FALSE) {
 #'
 #'   When column-binding, rows are matched by position, so all data
 #'   frames must have the same number of rows. To match by value, not
-#'   position, see [mutate-joins].
+#'   position, see mutate-joins.
 #' @param .id Data frame identifier.
 #'
 #'   When `.id` is supplied, a new column of identifiers is
@@ -101,14 +95,14 @@ arrange.Seurat <- function(.data, ..., .by_group = FALSE) {
 #'   names of the list. If no names are found a numeric sequence is
 #'   used instead.
 #' @param add.cell.ids from Seurat 3.0 A character vector of length(x = c(x, y)). Appends the corresponding values to the start of each objects' cell names.
-#' 
+#'
 #' @return `bind_rows()` and `bind_cols()` return the same type as
 #'   the first input, either a data frame, `tbl_df`, or `grouped_df`.
 #' @examples
 #' `%>%` = magrittr::`%>%`
-#' tt = pbmc_small 
+#' tt = pbmc_small
 #' bind_rows(    tt, tt  )
-#' 
+#'
 #' tt_bind = tt %>% select(nCount_RNA ,nFeature_RNA)
 #' tt %>% bind_cols(tt_bind)
 #'
@@ -117,9 +111,9 @@ NULL
 
 
 #' @rdname dplyr-methods
-#' 
+#'
 #' @inheritParams bind
-#' 
+#'
 #' @export
 #'
 bind_rows <- function(..., .id = NULL,  add.cell.ids = NULL) {
@@ -135,41 +129,41 @@ bind_rows.default <-  function(..., .id = NULL,  add.cell.ids = NULL)
 #' @importFrom rlang dots_values
 #' @importFrom rlang flatten_if
 #' @importFrom rlang is_spliced
-#' 
+#'
 #' @export
-#' 
+#'
 bind_rows.Seurat <- function(..., .id = NULL,  add.cell.ids = NULL)
 {
-  
+
   tts = flatten_if(dots_values(...), is_spliced)
-  
+
   # Strange error for Seurat merge
   # GetResidualSCTModel
   # close to a line as such
   # slot(object = object[[assay]], name = "SCTModel.list")
   # So I have to delete any sample of size 1 if I have calculated SCT
   # if()
-  # object@assays$SCT@SCTModel.list %>% map(~ .x@cell.attributes %>% nrow)
-  
+  # GetAssayData(object, slot = 'SCTModel.list', assay = "SCT") %>% map(~ .x@cell.attributes %>% nrow)
+
   # Check if cell with same name
-  merge(  tts[[1]] , y = tts[[2]],  add.cell.ids = add.cell.ids) 
-  
+  merge(  tts[[1]] , y = tts[[2]],  add.cell.ids = add.cell.ids)
+
 }
 
 bind_cols_ = function(..., .id = NULL){
-  
-  tts = flatten_if(dots_values(...), is_spliced) 
-  
-  tts[[1]]@meta.data = dplyr::bind_cols( tts[[1]]@meta.data, tts[[2]], .id = .id) 
-  
+
+  tts = flatten_if(dots_values(...), is_spliced)
+
+  tts[[1]]@meta.data = dplyr::bind_cols( tts[[1]][[]], tts[[2]], .id = .id)
+
   tts[[1]]
-  
+
 }
 
 #' @export
-#' 
+#'
 #' @inheritParams bind
-#' 
+#'
 #' @rdname dplyr-methods
 bind_cols <- function(..., .id = NULL) {
   UseMethod("bind_cols")
@@ -184,16 +178,16 @@ bind_cols.default <-  function(..., .id = NULL)
 #' @importFrom rlang dots_values
 #' @importFrom rlang flatten_if
 #' @importFrom rlang is_spliced
-#' 
+#'
 #' @export
-#' 
+#'
 bind_cols.Seurat <- bind_cols_
 
 
 #' distinct
-#' 
+#'
 #' @importFrom dplyr distinct
-#' 
+#'
 #' @param .data A tbl. (See dplyr)
 #' @param ... Data frames to combine (See dplyr)
 #' @param .keep_all If TRUE, keep all variables in .data. If a combination of ... is not distinct, this keeps the first row of values. (See dplyr)
@@ -203,11 +197,12 @@ bind_cols.Seurat <- bind_cols_
 #' @examples
 #'
 #' `%>%` = magrittr::`%>%`
+#' data("pbmc_small")
 #' pbmc_small %>%  distinct(groups)
 #'
 #' @rdname dplyr-methods
 #' @name distinct
-#' 
+#'
 #' @export
 NULL
 
@@ -215,13 +210,13 @@ NULL
 distinct.Seurat <- function (.data, ..., .keep_all = FALSE)
 {
   message("tidyseurat says: A data frame is returned for independent data analysis.")
-  
+
   .data %>%
     as_tibble() %>%
     dplyr::distinct(..., .keep_all = .keep_all)
-  
+
 }
- 
+
 
 #' Subset rows using column values
 #'
@@ -231,29 +226,11 @@ distinct.Seurat <- function (.data, ..., .keep_all = FALSE)
 #'
 #' dplyr is not yet smart enough to optimise filtering optimisation
 #' on grouped datasets that don't need grouped calculations. For this reason,
-#' filtering is often considerably faster on [ungroup()]ed data.
-#' 
+#' filtering is often considerably faster on ungroup()ed data.
+#'
 #' @importFrom dplyr filter
-#' 
-#' @section Useful filter functions:
-#'
-#' * [`==`], [`>`], [`>=`] etc
-#' * [`&`], [`|`], [`!`], [xor()]
-#' * [is.na()]
-#' * [between()], [near()]
-#'
-#' @section Grouped tibbles:
-#'
-#' Because filtering expressions are computed within groups, they may
-#' yield different results on grouped tibbles. This will be the case
-#' as soon as an aggregating, lagging, or ranking function is
-#' involved. Compare this ungrouped filtering:
 #'
 #'
-#' The former keeps rows with `mass` greater than the global average
-#' whereas the latter keeps rows with `mass` greater than the gender
-#'
-#' average.
 #' @family single table verbs
 #' @inheritParams arrange
 #' @param ... <[`tidy-eval`][dplyr_eval]> Logical predicates defined in
@@ -274,16 +251,15 @@ distinct.Seurat <- function (.data, ..., .keep_all = FALSE)
 #' implementations (methods) for other classes. See the documentation of
 #' individual methods for extra arguments and differences in behaviour.
 #'
-#' The following methods are currently available in loaded packages:
-#' @seealso [filter_all()], [filter_if()] and [filter_at()].
-#' 
+#'
 #' @rdname dplyr-methods
 #' @name filter
-#' 
+#'
 #' @export
 #' @examples
-#' 
+#'
 #' `%>%` = magrittr::`%>%`
+#' data("pbmc_small")
 #' pbmc_small %>%  filter(groups == "g1")
 #'
 #' # Learn more in ?dplyr_eval
@@ -293,20 +269,23 @@ NULL
 filter.Seurat <- function (.data, ..., .preserve = FALSE)
 {
   new_meta = .data %>% as_tibble() %>% dplyr::filter( ..., .preserve = .preserve) %>% as_meta_data(.data)
-  
+
   # Error if size == 0
   if(nrow(new_meta) == 0) stop("tidyseurat says: the resulting data container is empty. Seurat does not allow for empty containers.")
-  
-  new_obj = subset(.data,   cells = rownames(new_meta ))
-  #new_obj@meta.data = new_meta
+
+  new_obj = 
+    subset(.data,   cells = rownames(new_meta )) %>% 
+    
+    # Clean empty slots
+    clean_seurat_object()
   
   new_obj
-                   
+
 }
- 
+
 
 #' Group by one or more variables
-#' 
+#'
 #' @importFrom dplyr group_by_drop_default
 #' @importFrom dplyr group_by
 #'
@@ -326,9 +305,9 @@ filter.Seurat <- function (.data, ..., .preserve = FALSE)
 #'   This argument was previously called `add`, but that prevented
 #'   creating a new grouping variable called `add`, and conflicts with
 #'   our naming conventions.
-#' @param .drop When `.drop = TRUE`, empty groups are dropped. See [group_by_drop_default()] for
+#' @param .drop When `.drop = TRUE`, empty groups are dropped. See group_by_drop_default() for
 #'   what the default value is for this argument.
-#' @return A [grouped data frame][grouped_df()], unless the combination of `...` and `add`
+#' @return A grouped data frame, unless the combination of `...` and `add`
 #'   yields a non empty set of grouping columns, a regular (ungrouped) data frame
 #'   otherwise.
 #' @section Methods:
@@ -337,13 +316,14 @@ filter.Seurat <- function (.data, ..., .preserve = FALSE)
 #' individual methods for extra arguments and differences in behaviour.
 #'
 #' Methods available in currently loaded packages:
-#' 
+#'
 #' @rdname dplyr-methods
 #' @name group_by
-#' 
+#'
 #' @export
 #' @examples
 #' `%>%` = magrittr::`%>%`
+#' data("pbmc_small")
 #' pbmc_small %>%  group_by(groups)
 #'
 NULL
@@ -352,13 +332,13 @@ NULL
 group_by.Seurat <- function (.data, ..., .add = FALSE, .drop = group_by_drop_default(.data))
 {
   message("tidyseurat says: A data frame is returned for independent data analysis.")
-  
+
   .data %>%
     as_tibble() %>%
-    dplyr::group_by( ..., .add = .add, .drop = .drop) 
-  
+    dplyr::group_by( ..., .add = .add, .drop = .drop)
+
 }
- 
+
 
 #' Summarise each group to fewer rows
 #'
@@ -370,30 +350,10 @@ group_by.Seurat <- function (.data, ..., .add = FALSE, .drop = group_by_drop_def
 #' for each of the summary statistics that you have specified.
 #'
 #' `summarise()` and `summarize()` are synonyms.
-#' 
+#'
 #' @importFrom dplyr summarise
-#' 
-#' @section Useful functions:
 #'
-#' * Center: [mean()], [median()]
-#' * Spread: [sd()], [IQR()], [mad()]
-#' * Range: [min()], [max()], [quantile()]
-#' * Position: [first()], [last()], [nth()],
-#' * Count: [n()], [n_distinct()]
-#' * Logical: [any()], [all()]
 #'
-#' @section Backend variations:
-#'
-#' The data frame backend supports creating a variable and using it in the
-#' same summary. This means that previously created summary variables can be
-#' further transformed or combined within the summary, as in [mutate()].
-#' However, it also means that summary variables with the same names as previous
-#' variables overwrite them, making those variables unavailable to later summary
-#' variables.
-#'
-#' This behaviour may not be supported in other backends. To avoid unexpected
-#' results, consider using new names for your summary variables, especially when
-#' creating multiple summaries.
 #'
 #' @export
 #' @inheritParams arrange
@@ -405,31 +365,17 @@ group_by.Seurat <- function (.data, ..., .add = FALSE, .drop = group_by_drop_def
 #'   * A vector of length 1, e.g. `min(x)`, `n()`, or `sum(is.na(y))`.
 #'   * A vector of length `n`, e.g. `quantile()`.
 #'   * A data frame, to add multiple columns from a single expression.
+#'
 #' @family single table verbs
-#' @return
-#' An object _usually_ of the same type as `.data`.
+#' @return A tibble
 #'
-#' * The rows come from the underlying `group_keys()`.
-#' * The columns are a combination of the grouping keys and the summary
-#'   expressions that you provide.
-#' * If `x` is grouped by more than one variable, the output will be another
-#'   [grouped_df] with the right-most group removed.
-#' * If `x` is grouped by one variable, or is not grouped, the output will
-#'   be a [tibble].
-#' * Data frame attributes are **not** preserved, because `summarise()`
-#'   fundamentally creates a new data frame.
-#' @section Methods:
-#' This function is a **generic**, which means that packages can provide
-#' implementations (methods) for other classes. See the documentation of
-#' individual methods for extra arguments and differences in behaviour.
-#'
-#' The following methods are currently available in loaded packages:
-#' 
 #' @rdname dplyr-methods
 #' @name summarise
-#' 
+#'
 #' @examples
+#'
 #' `%>%` = magrittr::`%>%`
+#' data("pbmc_small")
 #' pbmc_small %>%  summarise(mean(nCount_RNA))
 #'
 #' @export
@@ -438,15 +384,15 @@ NULL
 #' @export
 summarise.Seurat <- function (.data, ...)
 {
-  
+
   message("tidyseurat says: A data frame is returned for independent data analysis.")
-  
+
   .data %>%
     as_tibble() %>%
     dplyr::summarise( ...)
-  
+
 }
- 
+
 
 #' Create, modify, and delete columns
 #'
@@ -454,23 +400,9 @@ summarise.Seurat <- function (.data, ...)
 #' `transmute()` adds new variables and drops existing ones.
 #' New variables overwrite existing variables of the same name.
 #' Variables can be removed by setting their value to `NULL`.
-#' 
+#'
 #' @importFrom dplyr mutate
-#' 
-#' @section Useful mutate functions:
 #'
-#' * [`+`], [`-`], [log()], etc., for their usual mathematical meanings
-#'
-#' * [lead()], [lag()]
-#'
-#' * [dense_rank()], [min_rank()], [percent_rank()], [row_number()],
-#'   [cume_dist()], [ntile()]
-#'
-#' * [cumsum()], [cummean()], [cummin()], [cummax()], [cumany()], [cumall()]
-#'
-#' * [na_if()], [coalesce()]
-#'
-#' * [if_else()], [recode()], [case_when()]
 #'
 #' @section Grouped tibbles:
 #'
@@ -483,10 +415,10 @@ summarise.Seurat <- function (.data, ...)
 #'
 #' The former normalises `mass` by the global average whereas the
 #' latter normalises by the averages within gender levels.
-#' 
+#'
 #' @rdname dplyr-methods
 #' @name mutate
-#' 
+#'
 #' @export
 #' @inheritParams arrange
 #' @param ... <[`tidy-eval`][dplyr_eval]> Name-value pairs.
@@ -530,6 +462,7 @@ summarise.Seurat <- function (.data, ...)
 #'
 #' @examples
 #' `%>%` = magrittr::`%>%`
+#' data("pbmc_small")
 #' pbmc_small %>%  mutate(nFeature_RNA = 1)
 #'
 NULL
@@ -537,37 +470,33 @@ NULL
 
 #' @importFrom dplyr mutate
 #' @importFrom rlang enquos
-#' 
+#'
 #' @export
 mutate.Seurat <- function(.data, ...)
 {
 
   # Check that we are not modifying a key column
-  cols = enquos(...) %>% names 
+  cols = enquos(...) %>% names
   if(intersect(cols, get_special_columns(.data) %>% c(get_needed_columns())) %>% length %>% gt(0))
     stop(sprintf("tidyseurat says: you are trying to mutate a column that is view only %s (it is not present in the meta.data). If you want to mutate a view-only column, make a copy and mutate that one.", get_special_columns(.data) %>% paste(collapse=", ")))
 
   .data@meta.data =
-    .data %>% 
+    .data %>%
     as_tibble %>%
-    dplyr::mutate( ...)  %>% 
+    dplyr::mutate( ...)  %>%
     as_meta_data(.data)
 
   .data
 }
 
- 
+
 #' Rename columns
 #'
 #' Rename individual variables using `new_name = old_name` syntax.
 #'
-#' @section Scoped selection and renaming:
 #'
-#' Use the three scoped variants ([rename_all()], [rename_if()], [rename_at()])
-#' to renaming a set of variables with a function.
-#' 
 #' @importFrom dplyr rename
-#' 
+#'
 #' @inheritParams arrange
 #' @param ... <[`tidy-select`][dplyr_select]> Use `new_name = old_name`
 #'   to rename selected variables.
@@ -584,82 +513,75 @@ mutate.Seurat <- function(.data, ...)
 #'
 #' The following methods are currently available in loaded packages:
 #' @family single table verbs
-#' 
+#'
 #' @rdname dplyr-methods
 #' @name rename
-#' 
+#'
 #' @export
 #' @examples
 #' `%>%` = magrittr::`%>%`
-#' pbmc_small %>%  rename(s_score = nFeature_RNA) 
-#' 
+#' data("pbmc_small")
+#' pbmc_small %>%  rename(s_score = nFeature_RNA)
+#'
 NULL
 
 #' @export
 rename.Seurat <- function(.data, ...)
 {
-  
+
   # Check that we are not modifying a key column
-  cols = tidyselect::eval_select(expr(c(...)), .data@meta.data) 
+  cols = tidyselect::eval_select(expr(c(...)), .data[[]])
   if(intersect(cols %>% names, get_special_columns(.data) %>% c(get_needed_columns())) %>% length %>% gt(0))
     stop(sprintf("tidyseurat says: you are trying to rename a column that is view only %s (it is not present in the meta.data). If you want to mutate a view-only column, make a copy and mutate that one.", get_special_columns(.data) %>% paste(collapse=", ")))
-  
-  .data@meta.data = dplyr::rename( .data@meta.data,  ...)
-  
+
+  .data@meta.data = dplyr::rename( .data[[]],  ...)
+
   .data
- 
-  
+
+
 }
- 
+
 
 #' Group input by rows
 #'
 #'
-#' See [this repository](https://github.com/jennybc/row-oriented-workflows)
-#' for alternative ways to perform row-wise operations.
-#'
 #' `rowwise()` is used for the results of [do()] when you
 #' create list-variables. It is also useful to support arbitrary
 #' complex operations that need to be applied to each row.
 #'
-#' Currently, rowwise grouping only works with data frames. Its
-#' main impact is to allow you to work with list-variables in
-#' [summarise()] and [mutate()] without having to
-#' use \code{[[1]]}. This makes `summarise()` on a rowwise tbl
-#' effectively equivalent to [plyr::ldply()].
 #'
 #' @importFrom dplyr rowwise
-#' 
+#'
 #' @param .data Input data frame.
 #' @param ... See dplyr::rowwise
-#' 
+#'
 #' @return A `tbl`
 #'
 #'   A `tbl`
 #'
 #' @rdname dplyr-methods
 #' @name rowwise
-#' 
+#'
 #' @export
 #' @examples
 #' `%>%` = magrittr::`%>%`
-#' 
+#'
 NULL
 
 #' @export
 rowwise.Seurat <- function(data, ...)
 {
   message("tidyseurat says: A data frame is returned for independent data analysis.")
-  
+
   data %>%
     as_tibble() %>%
     dplyr::rowwise(...)
-  
+
 }
- 
+
 
 #' Left join datasets
-#' 
+#'
 #' @importFrom dplyr count
 #' @importFrom dplyr left_join
 #'
@@ -674,14 +596,13 @@ rowwise.Seurat <- function(data, ...)
 #'
 #' @rdname dplyr-methods
 #' @name left_join
-#' 
+#'
 #' @export
 #'
 #' @examples
 #' `%>%` = magrittr::`%>%`
-#' 
-#' tt = pbmc_small 
-#' tt %>% left_join(tt %>% distinct(groups) %>% mutate(new_column = 1:2))
+#' data("pbmc_small")
+#' pbmc_small %>% left_join(pbmc_small %>% distinct(groups) %>% mutate(new_column = 1:2))
 #'
 NULL
 
@@ -689,30 +610,30 @@ NULL
 left_join.Seurat <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x", ".y"),
                                 ...)
 {
-  
-  x %>% 
+
+  x %>%
     as_tibble() %>%
     dplyr::left_join( y, by = by, copy = copy, suffix = suffix, ...) %>%
-    
+
     when(
-      
+
       # If duplicated cells returns tibble
       dplyr::count(., cell) %>% filter(n>1) %>% nrow %>% gt(0) ~ {
         message("tidyseurat says: This operation lead to duplicated cell names. A data frame is returned for independent data analysis.")
         (.)
       },
-      
+
       # Otherwise return updated tidyseurat
       ~ {
         x@meta.data = (.) %>% as_meta_data(x)
         x
-      } 
+      }
     )
-  
+
 }
 
 #' Inner join datasets
-#' 
+#'
 #' @importFrom dplyr pull
 #' @importFrom dplyr inner_join
 #'
@@ -727,13 +648,13 @@ left_join.Seurat <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x", ".
 #'
 #' @examples
 #' `%>%` = magrittr::`%>%`
-#' 
-#' tt = pbmc_small 
-#' tt %>% inner_join(tt %>% distinct(groups) %>% mutate(new_column = 1:2) %>% slice(1))
-#' 
+#'
+#' data("pbmc_small")
+#' pbmc_small %>% inner_join(pbmc_small %>% distinct(groups) %>% mutate(new_column = 1:2) %>% slice(1))
+#'
 #' @rdname dplyr-methods
 #' @name inner_join
-#' 
+#'
 #' @export
 NULL
 
@@ -743,27 +664,27 @@ inner_join.Seurat <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x", "
   x %>%
     as_tibble() %>%
     dplyr::inner_join( y, by = by, copy = copy, suffix = suffix, ...)  %>%
-    
+
     when(
-      
+
       # If duplicated cells returns tibble
       count(., cell) %>% filter(n>1) %>% nrow %>% gt(0) ~ {
         message("tidyseurat says: This operation lead to duplicated cell names. A data frame is returned for independent data analysis.")
         (.)
       },
-      
+
       # Otherwise return updated tidyseurat
       ~ {
         new_obj = subset(x,   cells =  pull(., "cell"))
         new_obj@meta.data = (.) %>% as_meta_data(new_obj)
         new_obj
-      } 
+      }
     )
-  
+
 }
 
 #' Right join datasets
-#' 
+#'
 #' @importFrom dplyr pull
 #' @importFrom dplyr right_join
 #'
@@ -778,13 +699,13 @@ inner_join.Seurat <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x", "
 #'
 #' @examples
 #' `%>%` = magrittr::`%>%`
-#' 
-#' tt = pbmc_small 
-#' tt %>% right_join(tt %>% distinct(groups) %>% mutate(new_column = 1:2) %>% slice(1))
-#' 
+#'
+#' data("pbmc_small")
+#' pbmc_small %>% right_join(pbmc_small %>% distinct(groups) %>% mutate(new_column = 1:2) %>% slice(1))
+#'
 #' @rdname dplyr-methods
 #' @name right_join
-#' 
+#'
 #' @export
 NULL
 
@@ -792,31 +713,31 @@ NULL
 right_join.Seurat <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x", ".y"),
                                  ...){
 
-  x %>% 
+  x %>%
     as_tibble() %>%
     dplyr::right_join( y, by = by, copy = copy, suffix = suffix, ...) %>%
-    
+
     when(
-      
+
       # If duplicated cells returns tibble
       count(., cell) %>% filter(n>1) %>% nrow %>% gt(0) ~ {
         message("tidyseurat says: This operation lead to duplicated cell names. A data frame is returned for independent data analysis.")
         (.)
       },
-      
+
       # Otherwise return updated tidyseurat
       ~ {
         new_obj = subset(x,   cells = (.) %>% pull("cell"))
         new_obj@meta.data = (.) %>% as_meta_data(new_obj)
         new_obj
-      } 
+      }
     )
-  
+
 }
 
 
 #' Full join datasets
-#' 
+#'
 #' @importFrom dplyr pull
 #' @importFrom dplyr full_join
 #'
@@ -831,13 +752,12 @@ right_join.Seurat <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x", "
 #'
 #' @examples
 #' `%>%` = magrittr::`%>%`
-#' 
-#' tt = pbmc_small 
-#' tt %>% full_join(tibble::tibble(groups = "g1", other=1:4)) 
+#' data("pbmc_small")
+#' pbmc_small %>% full_join(tibble::tibble(groups = "g1", other=1:4))
 #'
 #' @rdname dplyr-methods
 #' @name full_join
-#' 
+#'
 #' @export
 NULL
 
@@ -846,25 +766,25 @@ full_join.Seurat <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x", ".
                                 ...)
 {
 
- x %>% 
+ x %>%
     as_tibble() %>%
     dplyr::full_join( y, by = by, copy = copy, suffix = suffix, ...)  %>%
-    
+
     when(
-      
+
       # If duplicated cells returns tibble
       count(., cell) %>% filter(n>1) %>% nrow %>% gt(0) ~ {
         message("tidyseurat says: This operation lead to duplicated cell names. A data frame is returned for independent data analysis.")
         (.)
       },
-      
+
       # Otherwise return updated tidyseurat
       ~ {
         x@meta.data = (.) %>% as_meta_data(x)
         x
-      } 
+      }
     )
-  
+
 }
 
 #' Subset rows using their positions
@@ -874,17 +794,9 @@ full_join.Seurat <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x", ".
 #' to select, remove, and duplicate rows. It is accompanied by a number of
 #' helpers for common use cases:
 #'
-#' * `slice_head()` and `slice_tail()` select the first or last rows.
-#' * `slice_sample()` randomly selects rows.
-#' * `slice_min()` and `slice_max()` select rows with highest or lowest values
-#'   of a variable.
-#'
-#' If `.data` is a [grouped_df], the operation will be performed on each group,
-#' so that (e.g.) `slice_head(df, n = 5)` will select the first five rows in
-#' each group.
 #'
 #' @importFrom dplyr slice
-#' 
+#'
 #' @details
 #' Slice does not work with relational databases because they have no
 #' intrinsic notion of row order. If you want to perform the equivalent
@@ -900,12 +812,6 @@ full_join.Seurat <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x", ".
 #'   The values provided must be either all positive or all negative.
 #'   Indices beyond the number of rows in the input are silently ignored.
 #'
-#'   For `slice_helpers()`, these arguments are passed on to methods.
-#'
-#'
-#'   If `n` is greater than the number of rows in the group (or `prop > 1`),
-#'   the result will be silently truncated to the group size. If the
-#'   `prop`ortion of a group size is not an integer, it is rounded down.
 #' @return
 #' An object of the same type as `.data`. The output has the following
 #' properties:
@@ -914,43 +820,31 @@ full_join.Seurat <- function (x, y, by = NULL, copy = FALSE, suffix = c(".x", ".
 #' * Columns are not modified.
 #' * Groups are not modified.
 #' * Data frame attributes are preserved.
-#' @section Methods:
-#' These function are **generic**s, which means that packages can provide
-#' implementations (methods) for other classes. See the documentation of
-#' individual methods for extra arguments and differences in behaviour.
 #'
-#' Methods available in currently loaded packages:
-#'
-#' * `slice()`: \Sexpr[stage=render,results=rd]{dplyr:::methods_rd("slice")}.
-#' * `slice_head()`: \Sexpr[stage=render,results=rd]{dplyr:::methods_rd("slice_head")}.
-#' * `slice_tail()`: \Sexpr[stage=render,results=rd]{dplyr:::methods_rd("slice_tail")}.
-#' * `slice_min()`: \Sexpr[stage=render,results=rd]{dplyr:::methods_rd("slice_min")}.
-#' * `slice_max()`: \Sexpr[stage=render,results=rd]{dplyr:::methods_rd("slice_max")}.
-#' * `slice_sample()`: \Sexpr[stage=render,results=rd]{dplyr:::methods_rd("slice_sample")}.
-#' 
 #' @rdname dplyr-methods
 #' @name slice
-#' 
+#'
 #' @export
 #' @examples
-#' 
+#'
 #' `%>%` = magrittr::`%>%`
+#' data("pbmc_small")
 #' pbmc_small %>%  slice(1)
 NULL
 
 #' @export
 slice.Seurat <- function (.data, ..., .preserve = FALSE)
 {
-  new_meta = dplyr::slice(.data@meta.data, ..., .preserve = .preserve)
-  
+  new_meta = dplyr::slice(.data[[]], ..., .preserve = .preserve)
+
   # Error if size == 0
   if(nrow(new_meta) == 0) stop("tidyseurat says: the resulting data container is empty. Seurat does not allow for empty containers.")
-  
+
   new_obj = subset(.data,   cells = rownames(new_meta ))
   #new_obj@meta.data = new_meta
-  
+
   new_obj
-  
+
 }
 
 #' Subset columns using their names and types
@@ -960,17 +854,12 @@ slice.Seurat <- function (.data, ..., .preserve = FALSE)
 #' Select (and optionally rename) variables in a data frame, using a concise
 #' mini-language that makes it easy to refer to variables based on their name
 #' (e.g. `a:f` selects all columns from `a` on the left to `f` on the
-#' right). You can also use predicate functions like [is.numeric] to select
+#' right). You can also use predicate functions like is.numeric to select
 #' variables based on their properties.
 #'
 #'
-#' ## Overview of selection features
-#'
-#' ```{r, child = "man/rmd/overview.Rmd"}
-#' ```
-#' 
 #' @importFrom dplyr select
-#' 
+#'
 #' @inheritParams arrange
 #' @param ... <[`tidy-select`][dplyr_select]> One or more unquoted
 #'   expressions separated by commas. Variable names can be used as if they
@@ -986,76 +875,53 @@ slice.Seurat <- function (.data, ..., .preserve = FALSE)
 #' * Data frame attributes are preserved.
 #' * Groups are maintained; you can't select off grouping variables.
 #'
-#' @section Methods:
-#' This function is a **generic**, which means that packages can provide
-#' implementations (methods) for other classes. See the documentation of
-#' individual methods for extra arguments and differences in behaviour.
-#'
-#' The following methods are currently available in loaded packages:
-#' \Sexpr[stage=render,results=rd]{dplyr:::methods_rd("select")}.
 #'
 #' @examples
-#' 
+#'
 #' `%>%` = magrittr::`%>%`
+#' data("pbmc_small")
 #' pbmc_small %>%  select(cell, orig.ident )
 #'
 #' @family single table verbs
-#' 
+#'
 #' @rdname dplyr-methods
 #' @name select
-#' 
+#'
 #' @export
 NULL
 
 #' @export
 select.Seurat <- function (.data, ...)
 {
-   
+
   .data %>%
     as_tibble() %>%
     select_helper(...) %>%
     when(
-      
+
       # If key columns are missing
       (get_needed_columns() %in% colnames(.)) %>% all %>% `!` ~ {
         message("tidyseurat says: Key columns are missing. A data frame is returned for independent data analysis.")
         (.)
       },
-      
+
       # If valid seurat meta data
       ~ {
         .data@meta.data = (.) %>% as_meta_data(.data)
         .data
       }
     )
-  
+
 }
 
 
 #' Sample n rows from a table
 #'
 #' @description
-#' \Sexpr[results=rd, stage=render]{lifecycle::badge("superseded")}
-#' `sample_n()` and `sample_frac()` have been superseded in favour of
-#' [slice_sample()]. While they will not be deprecated in the near future,
-#' retirement means that we will only perform critical bug fixes, so we recommend
-#' moving to the newer alternative.
-#'
-#' These functions were superseded because we realised it was more convenient to
-#' have two mutually exclusive arguments to one function, rather than two
-#' separate functions. This also made it to clean up a few other smaller
-#' design issues with `sample_n()`/`sample_frac`:
-#'
-#' * The connection to `slice()` was not obvious.
-#' * The name of the first argument, `tbl`, is inconsistent with other
-#'   single table verbs which use `.data`.
-#' * The `size` argument uses tidy evaluation, which is surprising and
-#'   undocumented.
-#' * It was easier to remove the deprecated `.env` argument.
-#' * `...` was in a suboptimal position.
+#' Sample n rows from a table
 #'
 #' @importFrom dplyr sample_n
-#' 
+#'
 #' @keywords internal
 #' @param tbl A data.frame.
 #' @param size <[`tidy-select`][dplyr_select]>
@@ -1069,73 +935,92 @@ select.Seurat <- function (.data, ...)
 #' @param .env DEPRECATED.
 #' @param ... ignored
 #' @examples
-#' 
+#'
 #' `%>%` = magrittr::`%>%`
-#' pbmc_small %>%  sample_n(50) 
+#' data("pbmc_small")
+#' pbmc_small %>%  sample_n(50)
 #' pbmc_small %>%  sample_frac(0.1)
-#' 
+#'
 #' @return A Seurat object
 #'
 #' @rdname dplyr-methods
 #' @name sample_n
-#' 
+#'
 #' @export
 NULL
 
 #' @export
 sample_n.Seurat <- function(tbl, size, replace = FALSE,
                                 weight = NULL, .env = NULL, ...) {
+ 
+  # Solve CRAN NOTES
+  cell = NULL
+  . = NULL
   
   lifecycle::signal_superseded("1.0.0", "sample_n()", "slice_sample()")
+
+  new_meta = tbl[[]] %>%  as_tibble(rownames = "cell") %>% dplyr::sample_n( size, replace = replace, weight = weight, .env = .env, ...)
   
-  new_meta = tbl@meta.data %>% dplyr::sample_n( size, replace = replace, weight = weight, .env = .env, ...) 
-  new_obj = subset(tbl,   cells = rownames(new_meta ))
-  new_obj@meta.data = new_meta
+  count_cells = new_meta %>% select(cell) %>% count(cell)
   
-  new_obj %>%
-    
-    # If replace return simple tibble because is not trivial to build 
-    # a redundant Seurat object and it would not make much sense
-    when(
-      replace ~ {
-        message("tidyseurat says: When sampling with replacement a data frame is returned for independent data analysis.")
-        as_tibble(.)
-      },
-      ~ (.)
-    )
+  # If repeted cells
+  if(count_cells$n %>% max() %>% gt(1)){
+    message("tidyseurat says: When sampling with replacement a data frame is returned for independent data analysis.")
+    tbl %>% 
+      as_tibble() %>% 
+      right_join(new_meta %>% select(cell),  by = "cell")
+  }  else{
+    new_obj = subset(tbl,   cells = new_meta %>% pull(cell))
+    new_obj@meta.data = 
+      new_meta %>% 
+      data.frame(row.names=pull(.,cell), check.names = FALSE) %>%
+      select(-cell) 
+    new_obj
+  }
   
+  
+
+
+
 }
 
 #' @importFrom dplyr sample_frac
-#' 
+#'
 #' @rdname dplyr-methods
 #' @name sample_frac
-#' 
+#'
 #' @export
 NULL
 
 #' @export
 sample_frac.Seurat <- function(tbl, size = 1, replace = FALSE,
                                    weight = NULL, .env = NULL, ...) {
+  
+  # Solve CRAN NOTES
+  cell = NULL
+  . = NULL
 
   lifecycle::signal_superseded("1.0.0", "sample_frac()", "slice_sample()")
+
+  new_meta = tbl[[]] %>%  as_tibble(rownames = "cell") %>% dplyr::sample_frac( size, replace = replace, weight = weight, .env = .env, ...)
   
-  new_meta = tbl@meta.data %>% dplyr::sample_frac( size, replace = replace, weight = weight, .env = .env, ...) 
-  new_obj = subset(tbl,   cells = rownames(new_meta ))
-  new_obj@meta.data = new_meta
-  
-  new_obj %>%
-    
-    # If replace return simple tibble because is not trivial to build 
-    # a redundant Seurat object and it would not make much sense
-    when(
-      replace ~ {
-        message("tidyseurat says: When sampling with replacement a data frame is returned for independent data analysis.")
-        as_tibble(.)
-      },
-      ~ (.)
-    )
+  count_cells = new_meta %>% select(cell) %>% count(cell)
   
+  # If repeted cells
+  if(count_cells$n %>% max() %>% gt(1)){
+    message("tidyseurat says: When sampling with replacement a data frame is returned for independent data analysis.")
+    tbl %>% 
+      as_tibble() %>% 
+      right_join(new_meta %>% select(cell),  by = "cell")
+  }  else{
+    new_obj = subset(tbl,   cells = new_meta %>% pull(cell))
+    new_obj@meta.data = 
+      new_meta %>% 
+      data.frame(row.names=pull(.,cell), check.names = FALSE) %>%
+      select(-cell) 
+    new_obj
+  }
+
 }
 
 
@@ -1174,11 +1059,12 @@ sample_frac.Seurat <- function(tbl, size = 1, replace = FALSE,
 #' group transiently, so the output has the same groups as the input.
 #' @export
 #' @examples
-#' 
+#'
 #' `%>%` = magrittr::`%>%`
+#' data("pbmc_small")
 #' pbmc_small %>%  count(groups)
-#' 
-#' 
+#'
+#'
 count <- function(x, ..., wt = NULL, sort = FALSE, name = NULL, .drop = group_by_drop_default(x)) {
 UseMethod("count")
 }
@@ -1199,13 +1085,13 @@ count.default <- function(x, ..., wt = NULL, sort = FALSE, name = NULL, .drop =
 
 #' @export
 count.Seurat <- function(x, ..., wt = NULL, sort = FALSE, name = NULL, .drop = group_by_drop_default(x)) {
-  
+
   message("tidyseurat says: A data frame is returned for independent data analysis.")
-  
+
   x %>%
     as_tibble() %>%
     dplyr::count(  ..., wt = !!enquo(wt), sort = sort, name = name, .drop = .drop)
-  
+
 }
 
 #' @export
@@ -1217,9 +1103,9 @@ add_count <- function(x, ..., wt = NULL, sort = FALSE, name = NULL, .drop = grou
 #' @export
 #' @rdname count
 add_count.default <- function(x, ..., wt = NULL, sort = FALSE, name = NULL, .drop = group_by_drop_default(x)) {
- 
+
   dplyr::add_count(x=x, ..., wt = !!enquo(wt), sort = sort, name = name, .drop = .drop)
-  
+
 }
 
 #' @export
@@ -1227,13 +1113,13 @@ add_count.default <- function(x, ..., wt = NULL, sort = FALSE, name = NULL, .dro
 add_count.Seurat <- function(x, ..., wt = NULL, sort = FALSE, name = NULL, .drop = group_by_drop_default(x)) {
 
   x@meta.data =
-    x %>% 
+    x %>%
     as_tibble %>%
-    dplyr::add_count(..., wt = !!enquo(wt), sort = sort, name = name, .drop = .drop)  %>% 
+    dplyr::add_count(..., wt = !!enquo(wt), sort = sort, name = name, .drop = .drop)  %>%
     as_meta_data(x)
-  
+
   x
-  
+
 }
 
 #' Extract a single column
@@ -1243,42 +1129,36 @@ add_count.Seurat <- function(x, ..., wt = NULL, sort = FALSE, name = NULL, .drop
 #' name the output.
 #'
 #' @importFrom dplyr pull
-#' 
+#'
 #' @inheritParams arrange
 #' @inheritParams tidyselect::vars_pull
 #' @param name An optional parameter that specifies the column to be used
 #'   as names for a named vector. Specified in a similar manner as \code{var}.
 #' @param ... For use by methods.
 #' @return A vector the same size as `.data`.
-#' @section Methods:
-#' This function is a **generic**, which means that packages can provide
-#' implementations (methods) for other classes. See the documentation of
-#' individual methods for extra arguments and differences in behaviour.
 #'
-#' The following methods are currently available in loaded packages:
-#' \Sexpr[stage=render,results=rd]{dplyr:::methods_rd("pull")}.
-#' 
 #' @rdname dplyr-methods
 #' @name pull
-#' 
+#'
 #' @export
 #' @examples
-#' 
+#'
 #' `%>%` = magrittr::`%>%`
+#' data("pbmc_small")
 #' pbmc_small %>%  pull(groups)
-#' 
+#'
 NULL
 
 #' @export
 pull.Seurat <- function(.data, var = -1, name = NULL, ...) {
   var = enquo(var)
   name = enquo(name)
-  
+
   message("tidyseurat says: A data frame is returned for independent data analysis.")
-  
+
   .data %>%
     as_tibble() %>%
     dplyr::pull( var = !!var, name = !!name, ...)
-  
-  
+
+
 }
